/// <reference types="react" />
import * as React from 'react';
import { IDomain, IHpSliderHandleValues } from './interfaces';
import { IHpSliderHandleMoved } from './components/handle';
import { EnumHandleType } from './enums';
import { IHpSliderScss } from '../sass/styles';
export interface IHpSliderBaseProps {
    scss: IHpSliderScss;
    /**
     * The (real number, linear) domain provided for convenience of a particluar applications.
     * See that IDomain<T> is a generic interface - in the future there can be a different (unit) type applied.
     *
     * For example, let's say:
     * - the slider is 1024px wide
     * - we can set voltage to a device in [-12V, +12V] range
     *
     * The domain in volage in [-12V, +12V] range.
     */
    domain: IDomain<number>;
    /**
     * Value in domain (units), not pixels
     */
    handleValues: IHpSliderHandleValues<number>;
    /**
     * Renders an additional element called a "drag bar", since it is designed for dragging.
     */
    displayDragBar: boolean;
    handleMoved: IHpSliderHandleMoved;
    refCallback?: (svg: HTMLElement) => void;
}
export interface IHpSliderBaseState {
    pressedHandle?: EnumHandleType | null;
    previousScreenX?: number;
}
export declare class HpSliderBase extends React.Component<IHpSliderBaseProps, IHpSliderBaseState> {
    constructor(props: any);
    componentDidMount(): void;
    componentWillUnmount(): void;
    getSliderStyle: () => React.CSSProperties;
    getSvgStyle: () => React.CSSProperties;
    getValueOfPressedHandle: () => number;
    globalMouseUp: () => boolean;
    /**
     * Unfortunately, we cannot rely on props values for left, right handle position completely.
     * These can be provided wrong, but the component should render correctly or
     * as correctly as possible - (left handle should be always before the right handle).
     */
    correctedHandleValues: () => number[];
    acceptNewValueForHandle(newValue: number | number[]): boolean;
    render(): JSX.Element;
}
