"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
}
Object.defineProperty(exports, "__esModule", { value: true });
var _ = __importStar(require("lodash"));
var React = __importStar(require("react"));
var calculations_1 = require("./calculations");
var handle_1 = require("./components/handle");
var enums_1 = require("./enums");
var HpSliderBase = /** @class */ (function (_super) {
    __extends(HpSliderBase, _super);
    function HpSliderBase(props) {
        var _this = _super.call(this, props) || this;
        _this.getSliderStyle = function () {
            var result = {
                width: _this.props.scss.widthPx,
                position: "relative"
            };
            return result;
        };
        _this.getSvgStyle = function () {
            var result = {
                width: _this.props.scss.widthPx,
                position: "absolute",
                backgroundColor: "white"
            };
            return result;
        };
        _this.getValueOfPressedHandle = function () {
            var result = 0;
            switch (_this.state.pressedHandle) {
                case enums_1.EnumHandleType.Left:
                    result = _this.props.handleValues.left;
                    break;
                case enums_1.EnumHandleType.Right:
                    result = _this.props.handleValues.right;
                    break;
            }
            return result;
        };
        _this.globalMouseUp = function () {
            _this.setState({ previousScreenX: null, pressedHandle: null });
            return true;
        };
        /**
         * Unfortunately, we cannot rely on props values for left, right handle position completely.
         * These can be provided wrong, but the component should render correctly or
         * as correctly as possible - (left handle should be always before the right handle).
         */
        _this.correctedHandleValues = function () {
            var handleWidthInDomainUnits = calculations_1.calculations.expressLengthPxInDomain(_this.props.domain, _this.props.scss, _this.props.scss.handleWidthPx);
            var result = [_this.props.handleValues.left, _this.props.handleValues.right];
            var handleDifferenceInDomainUnits = _this.props.handleValues.right - _this.props.handleValues.left;
            if (handleDifferenceInDomainUnits < 2 * handleWidthInDomainUnits) {
                //do not touch the left handle... move the right one !
                if (_this.props.handleValues.left - _this.props.domain.domainMin < handleWidthInDomainUnits)
                    result[1] = _this.props.handleValues.left + 2 * handleWidthInDomainUnits;
                else
                    result[0] = _this.props.handleValues.right - 2 * handleWidthInDomainUnits;
            }
            return result;
        };
        _this.state = {
            pressedHandle: null,
            previousScreenX: null
        };
        return _this;
    }
    HpSliderBase.prototype.componentDidMount = function () {
        window.addEventListener('mouseup', this.globalMouseUp, false);
    };
    HpSliderBase.prototype.componentWillUnmount = function () {
        window.removeEventListener('mouseup', this.globalMouseUp);
    };
    HpSliderBase.prototype.acceptNewValueForHandle = function (newValue) {
        var result = true;
        var valueLeft = null;
        var valueRight = null;
        switch (this.state.pressedHandle) {
            case enums_1.EnumHandleType.Left:
                valueLeft = _.isNumber(newValue) ? newValue : valueLeft;
                break;
            case enums_1.EnumHandleType.Right:
                valueRight = _.isNumber(newValue) ? newValue : valueRight;
                break;
            case enums_1.EnumHandleType.DragBar:
                valueLeft = _.isArray(newValue) ? newValue[0] : valueLeft;
                valueRight = _.isArray(newValue) ? newValue[1] : valueRight;
                break;
        }
        if (_.isNumber(valueLeft))
            result = result && _.inRange(valueLeft, this.props.domain.domainMin, this.props.domain.domainMax);
        if (_.isNumber(valueRight))
            result = result && _.inRange(valueRight, this.props.domain.domainMin, this.props.domain.domainMax);
        return result;
    };
    HpSliderBase.prototype.render = function () {
        var _this = this;
        var correctedValues = this.correctedHandleValues();
        return (React.createElement("div", { className: "hp-slider", ref: function (div) {
                if (_.isObject(div) && _.isFunction(_this.props.refCallback)) {
                    _this.props.refCallback(div);
                }
            } },
            this.props.children,
            React.createElement("div", { style: { width: this.props.scss.widthPx, position: "absolute" }, className: "hp-slider-inner-border-rect" }),
            React.createElement(handle_1.HpSliderHandle, { key: "handle_left", domain: this.props.domain, scss: this.props.scss, value: correctedValues[0], handleType: enums_1.EnumHandleType.Left, onMoved: function (newValue, type) {
                    if (_this.acceptNewValueForHandle(newValue))
                        _this.props.handleMoved(newValue, type);
                }, onPressed: function (isPressed, type) {
                    _this.setState({ pressedHandle: isPressed ? type : null });
                } }),
            this.props.displayDragBar &&
                React.createElement(handle_1.HpSliderHandle, { scss: this.props.scss, domain: this.props.domain, handleType: enums_1.EnumHandleType.DragBar, onMoved: function (newValue, type) {
                        if (_this.acceptNewValueForHandle(newValue))
                            _this.props.handleMoved(newValue, type);
                    }, onPressed: function (isPressed, type) {
                        _this.setState({ pressedHandle: isPressed ? type : null });
                    }, value: correctedValues, key: "handle_dragBar" }),
            React.createElement(handle_1.HpSliderHandle, { key: "handle_right", domain: this.props.domain, scss: this.props.scss, value: correctedValues[1], handleType: enums_1.EnumHandleType.Right, onMoved: function (newValue, type) {
                    if (_this.acceptNewValueForHandle(newValue))
                        _this.props.handleMoved(newValue, type);
                }, onPressed: function (isPressed, type) {
                    _this.setState({ pressedHandle: isPressed ? type : null });
                } })));
    };
    return HpSliderBase;
}(React.Component));
exports.HpSliderBase = HpSliderBase;
//# sourceMappingURL=base-component.js.map