"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
}
Object.defineProperty(exports, "__esModule", { value: true });
var React = __importStar(require("react"));
var _ = __importStar(require("lodash"));
var common_1 = require("../common");
var calculations_1 = require("../calculations");
var enums_1 = require("../enums");
var HpSliderHandle = /** @class */ (function (_super) {
    __extends(HpSliderHandle, _super);
    function HpSliderHandle(props) {
        var _this = _super.call(this, props) || this;
        _this.getHandleStyle = function () {
            var leftPx = 0;
            var widthPx = 0;
            switch (_this.props.handleType) {
                case enums_1.EnumHandleType.Left:
                case enums_1.EnumHandleType.Right:
                    var value = _.isNumber(_this.props.value) ? _this.props.value : 0;
                    leftPx = calculations_1.calculations.translateValueToHandleLeftPositionPx(_this.props.domain, _this.props.scss, _this.props.handleType, value);
                    widthPx = _this.props.scss.handleWidthPx;
                    break;
                case enums_1.EnumHandleType.DragBar:
                    leftPx = calculations_1.calculations.translateValueToHandleLeftPositionPx(_this.props.domain, _this.props.scss, _this.props.handleType, _this.props.value[0]) +
                        _this.props.scss.handleWidthPx;
                    /**
                     * Keep in mind:
                     * - the left edge of left handle (of type EnumHandleType.Left) represents this.props.value[0] and
                     * - the right edge of right handle (of type EnumHandleType.Right) represents this.props.value[1].
                     * So since we have additional handles to display (EnumHandleType.Left, EnumHandleType.Right),
                     * EnumHandleType.Bar cannot occupy the whole screen space that domainLengthSliderRepresents holds.
                     */
                    var domainLengthSliderRepresents = (_this.props.value[1] - _this.props.value[0]);
                    var domainLengthHandleRepresents = calculations_1.calculations.expressLengthPxInDomain(_this.props.domain, _this.props.scss, _this.props.scss.handleWidthPx);
                    widthPx = calculations_1.calculations.expressDomainLengthInPx(_this.props.domain, _this.props.scss, domainLengthSliderRepresents - 2 * domainLengthHandleRepresents);
                    break;
            }
            var result = {
                left: leftPx,
                width: widthPx >= 1 ? widthPx : 1,
                position: "absolute",
                cursor: "pointer",
            };
            return result;
        };
        _this.getClassName = function () {
            var result = ["hp-slider-handle"];
            if (_this.state.isPressed)
                result.push("hp-slider-handle-pressed");
            switch (_this.props.handleType) {
                case enums_1.EnumHandleType.DragBar:
                    result.push("hp-slider-handle-dragBar");
                    break;
                case enums_1.EnumHandleType.Left:
                    result.push("hp-slider-handle-left");
                    break;
                case enums_1.EnumHandleType.Right:
                    result.push("hp-slider-handle-right");
                    break;
            }
            return _.join(result, " ");
        };
        _this.globalMouseUp = function (e) {
            _this.setState({
                isPressed: false,
                previousScreenX: null
            });
            if (_.isFunction(_this.props.onPressed))
                _this.props.onPressed(false, _this.props.handleType);
            return true;
        };
        _this.globalMouseMove = function (e) {
            if (_this.state.isPressed) {
                //for a positive delta, handle bar was moved rightwards,
                //for a negative delta, handle was moved leftwards
                var deltaPx = e.screenX - _this.state.previousScreenX;
                var deltaDomain = calculations_1.calculations.expressLengthPxInDomain(_this.props.domain, _this.props.scss, deltaPx);
                _this.setState({ previousScreenX: e.screenX });
                if (_.isFunction(_this.props.onMoved)) {
                    switch (_this.props.handleType) {
                        case enums_1.EnumHandleType.Left:
                        case enums_1.EnumHandleType.Right:
                            var point = _.isNumber(_this.props.value) ? _this.props.value : 0;
                            _this.props.onMoved(point + deltaDomain, _this.props.handleType);
                            break;
                        case enums_1.EnumHandleType.DragBar:
                            if (!_.isArray(_this.props.value))
                                return;
                            var vector = [_this.props.value[0] + deltaDomain, _this.props.value[1] + deltaDomain];
                            _this.props.onMoved(vector, _this.props.handleType);
                            break;
                    }
                }
            }
            return common_1.common.pauseEvent(e);
        };
        _this.state = {
            isPressed: false,
            previousScreenX: null
        };
        return _this;
    }
    HpSliderHandle.prototype.componentDidMount = function () {
        window.addEventListener('mouseup', this.globalMouseUp, false);
        window.addEventListener('mousemove', this.globalMouseMove, false);
    };
    HpSliderHandle.prototype.componentWillUnmount = function () {
        window.removeEventListener('mouseup', this.globalMouseUp);
        window.removeEventListener('mousemove', this.globalMouseMove);
    };
    HpSliderHandle.prototype.render = function () {
        var _this = this;
        var self = this;
        return React.createElement("div", { className: this.getClassName(), style: this.getHandleStyle(), onMouseDown: function (e) {
                _this.setState({ isPressed: true, previousScreenX: e.screenX });
                if (_.isFunction(_this.props.onPressed))
                    _this.props.onPressed(true, _this.props.handleType);
            } });
    };
    return HpSliderHandle;
}(React.Component));
exports.HpSliderHandle = HpSliderHandle;
//# sourceMappingURL=handle.js.map