"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
}
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importDefault(require("react"));
var d3 = __importStar(require("d3"));
var lodash_1 = __importDefault(require("lodash"));
var calculations_1 = require("./calculations");
var time_series_1 = require("./components/time-series");
var date_time_axis_1 = require("./components/date-time-axis");
var value_axis_1 = require("./components/value-axis");
var EnumHpTimeSeriesChartMode;
(function (EnumHpTimeSeriesChartMode) {
    EnumHpTimeSeriesChartMode[EnumHpTimeSeriesChartMode["Standalone"] = 0] = "Standalone";
    EnumHpTimeSeriesChartMode[EnumHpTimeSeriesChartMode["SliderEmbedded"] = 1] = "SliderEmbedded";
})(EnumHpTimeSeriesChartMode = exports.EnumHpTimeSeriesChartMode || (exports.EnumHpTimeSeriesChartMode = {}));
exports.HpTimeSeriesChartBase = function (props) {
    var _a = lodash_1.default.isFunction(props.scaleLinearDomain) ?
        (props.scaleLinearDomain(props.state.yMin, props.state.yMax)) :
        { yMin: props.state.yMin, yMax: props.state.yMax }, yMin = _a.yMin, yMax = _a.yMax;
    var getStyle = function () {
        if (lodash_1.default.isUndefined(props.mode))
            return {};
        switch (props.mode) {
            case EnumHpTimeSeriesChartMode.Standalone:
                return {};
            case EnumHpTimeSeriesChartMode.SliderEmbedded:
                return {
                    position: "absolute"
                };
        }
    };
    var displayAxis = function () {
        return (lodash_1.default.isUndefined(props.mode) || (props.mode == EnumHpTimeSeriesChartMode.Standalone));
    };
    /**
     * converts x (on screen) coordinate to unix date-time
     */
    var convertXToUnix = function (x) {
        return props.state.windowUnixFrom + (x - props.scss.paddingLeftPx) /
            (props.scss.widthPx - props.scss.paddingLeftPx - props.scss.paddingRightPx) *
            (props.state.windowUnixTo - props.state.windowUnixFrom);
    };
    var getXScale = function () {
        return d3.scaleTime()
            .domain([props.state.windowUnixFrom, props.state.windowUnixTo])
            .range([props.scss.paddingLeftPx, props.scss.widthPx - props.scss.paddingRightPx]);
    };
    var getYScale = function () {
        return d3.scaleLinear()
            .domain([yMin, yMax])
            .range([props.scss.heightPx - props.scss.paddingTopPx - props.scss.paddingBottomPx,
            props.scss.paddingTopPx]);
    };
    var xScale = getXScale();
    var yScale = getYScale();
    return (react_1.default.createElement("svg", { style: getStyle(), ref: function (svg) {
            if (lodash_1.default.isObject(svg)) {
                if (lodash_1.default.isFunction(props.refCallback))
                    props.refCallback(svg);
                if (lodash_1.default.isObject(props.interactions)) {
                    if (lodash_1.default.isFunction(props.interactions.mouseButtonDown))
                        svg.onmousedown = function (ev) { return props.interactions.mouseButtonDown(convertXToUnix(ev.offsetX)); };
                    if (lodash_1.default.isFunction(props.interactions.mouseButtonUp))
                        svg.onmouseup = function (ev) { return props.interactions.mouseButtonUp(convertXToUnix(ev.offsetX)); };
                }
            }
        }, width: props.scss.widthPx, height: props.scss.heightPx },
        react_1.default.createElement(time_series_1.TimeSeries, { xScale: xScale, yScale: yScale, yMin: yMin, yMax: yMax, chartTimeSeries: calculations_1.hpTimeSeriesChartCalculations.convertToOnScreenTimeSeries(props.state.series, props.state.windowUnixFrom, props.state.windowUnixTo, props.scss.widthPx) }),
        displayAxis() && react_1.default.createElement(date_time_axis_1.DateTimeAxis, { xScale: xScale, scss: props.scss, tickFormat: props.dateTimeAxisTickFormat }),
        displayAxis() && react_1.default.createElement(value_axis_1.ValueAxis, { yScale: yScale, scss: props.scss })));
};
//# sourceMappingURL=base-component.js.map