"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
}
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var _ = __importStar(require("lodash"));
var d3 = __importStar(require("d3"));
var React = __importStar(require("react"));
// Line-Time-Series prefix in key name must stay here, since DottedLine type of series draws two types of chart one one another
var getTimeSeriesKey = function (ctx) { return "Line-Time-Series|" + ctx.ts.name + "|" + ctx.ts.fragmentId; };
var transformBucketsToAreaTimeSeries = function (buckets) {
    var result = [];
    _.each(buckets, function (b) {
        switch (b.numberOfSamples) {
            case 1:
                result.push({ x: b.date, y0: b.minY, y1: b.minY });
                break;
            case 2:
                result.push({ x: new Date(b.firstSample.unix), y0: b.firstSample.value, y1: b.firstSample.value });
                result.push({ x: new Date(b.lastSample.unix), y0: b.lastSample.value, y1: b.lastSample.value });
                break;
            default:
                result.push({ x: new Date(b.firstSample.unix), y0: b.firstSample.value, y1: b.firstSample.value });
                result.push({ x: b.date, y0: b.minY, y1: b.maxY });
                result.push({ x: new Date(b.lastSample.unix), y0: b.lastSample.value, y1: b.lastSample.value });
                break;
        }
    });
    return result;
};
var getSvgAreaPath = function (ctx) {
    var self = _this;
    var area = d3.area()
        .x(function (d) {
        return ctx.xScale(d.x);
    })
        .y0(function (d) { return ctx.yScale(d.y0); })
        .y1(function (d) { return ctx.yScale(d.y1); });
    var buckets = _.concat(_.isObject(ctx.ts.buckets.shadowPreceding) ? [ctx.ts.buckets.shadowPreceding] : [], ctx.ts.buckets.buckets, _.isObject(ctx.ts.buckets.shadowSucceeding) ? [ctx.ts.buckets.shadowSucceeding] : []);
    return area(transformBucketsToAreaTimeSeries(buckets));
};
exports.renderLineTimeSeries = function (ctx) {
    return (React.createElement("path", { key: getTimeSeriesKey(ctx), d: getSvgAreaPath(ctx), fill: ctx.ts.color, stroke: ctx.ts.color }));
};
//# sourceMappingURL=line-time-series.js.map