"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
}
Object.defineProperty(exports, "__esModule", { value: true });
var _ = __importStar(require("lodash"));
var dateFns = __importStar(require("date-fns"));
var SAMPLE_VALUE_MAX = 150;
var SECONDS_PER_SAMPLE = 60;
var buildInitialState = function () {
    var currentDate = new Date();
    var result = {
        series: [{
                name: "red",
                color: "red",
                points: [],
                unixToIndexMap: new Map(),
                unixFrom: currentDate.getTime(),
                unixTo: currentDate.getTime(),
            }],
        dateRangeUnixFrom: currentDate.getTime(),
        dateRangeUnixTo: dateFns.addHours(currentDate, 6).getTime(),
        isDataLoading: false,
        windowUnixFrom: currentDate.getTime(),
        windowUnixTo: dateFns.addHours(currentDate, 6).getTime(),
        yMin: 0,
        yMax: 0,
        rangeSelections: []
    };
    return result;
};
/**
 * For testing only
 */
var randomContinousUnixTimePoints = function (dateFrom, dateTo) {
    var referenceDate = new Date(dateFrom.getTime());
    var result = [];
    var currentValue = _.random(50, 100);
    var iterationIndex = 0;
    while (dateFns.isBefore(referenceDate, dateTo)) {
        result.push({
            unix: referenceDate.getTime(),
            value: currentValue
        });
        referenceDate = dateFns.addSeconds(referenceDate, _.random(1, 5) * SECONDS_PER_SAMPLE);
        var chanceForChangeIndexValue = _.random(0, 100);
        if (_.inRange(chanceForChangeIndexValue, 0, 10)) {
            currentValue += 40 - _.random(0, 80);
        }
        if (_.inRange(chanceForChangeIndexValue, 10, 30)) {
            currentValue += 20 - _.random(0, 40);
        }
        iterationIndex++;
    }
    return result;
};
/**
 * For testing only
 */
var randomIntermittentUnixTimePoints = function (dateRangeDateFrom, dateRangeDateTo) {
    var result = [];
    var holeCounter = 0;
    for (var _i = 0, _a = randomContinousUnixTimePoints(dateRangeDateFrom, dateRangeDateTo); _i < _a.length; _i++) {
        var p = _a[_i];
        if ((holeCounter == 0) && (2 <= _.random(0, 10)))
            holeCounter = _.random(2, 8);
        (holeCounter > 0) ? holeCounter-- : result.push(p);
    }
    return result;
};
/**
 * For testing only
 */
var squareWaveTimePoints = function (dateRangeDateFrom, dateRangeDateTo) {
    var referenceDate = new Date(dateRangeDateFrom.getTime());
    var result = [];
    var iterationIndex = 0;
    while (dateFns.isBefore(referenceDate, dateRangeDateTo)) {
        result.push({
            unix: referenceDate.getTime(),
            value: dateFns.getHours(referenceDate.getTime()) % 2 ? 1 : 0
        });
        referenceDate = dateFns.addSeconds(referenceDate, SECONDS_PER_SAMPLE);
        iterationIndex++;
        if (iterationIndex % 50000 == 0) {
            console.log("Generated for " + dateFns.format(referenceDate, "YYYY-MM-DD HH:mm"));
        }
    }
    return result;
};
exports.hpTimeSeriesChartReducerAuxFunctions = {
    buildInitialState: buildInitialState,
    randomContinousUnixTimePoints: randomContinousUnixTimePoints,
    randomIntermittentUnixTimePoints: randomIntermittentUnixTimePoints,
    squareWaveTimePoints: squareWaveTimePoints
};
//# sourceMappingURL=reducers-aux.js.map