"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
}
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Declares default reducer function implementations
 * that can be reused by a concrete screen reducer
 */
var _ = __importStar(require("lodash"));
var actionTypes = __importStar(require("./action-types"));
var enums_1 = require("./state/enums");
var unix_index_map_1 = require("./calculations/unix-index-map");
var reducers_aux_1 = require("./reducers-aux");
var actions_1 = require("./actions");
var initialState = reducers_aux_1.hpTimeSeriesChartReducerAuxFunctions.buildInitialState();
/**
 * Builds (initial) chart state with several outer settings
 */
var generateRandomData = function (state, action) {
    return setData(state, new actions_1.SetDataAction([{
            color: "orange",
            name: "Random Series",
            points: reducers_aux_1.hpTimeSeriesChartReducerAuxFunctions.randomContinousUnixTimePoints(action.from, action.to),
            type: enums_1.EnumTimeSeriesType.Line,
        }]));
};
var setData = function (state, action) {
    var stateWithSeries = {
        series: _.map(action.series, function (el) { return ({
            color: el.color,
            unixFrom: _.isEmpty(el.points) ? Number.MAX_VALUE : _.first(el.points).unix,
            unixTo: _.isEmpty(el.points) ? Number.MIN_VALUE : _.last(el.points).unix,
            points: el.points,
            name: el.name,
            type: el.type,
            unixToIndexMap: unix_index_map_1.unixIndexMapCalculations.createUnixToIndexMap(el.points)
        }); })
    };
    var allValues = _.reduceRight(stateWithSeries.series, function (accumulator, series) {
        return _.concat(accumulator, _.map(series.points, function (el) { return el.value; }));
    }, []);
    var unixFrom = _.min(_.concat(_.map(stateWithSeries.series, function (el) { return el.unixFrom; })));
    var unixTo = _.max(_.concat(_.map(stateWithSeries.series, function (el) { return el.unixTo; })));
    var stateWithUnixFromTo = _.extend(stateWithSeries, {
        dateRangeUnixFrom: unixFrom,
        dateRangeUnixTo: unixTo,
        windowUnixFrom: unixFrom,
        windowUnixTo: unixTo,
        yMin: _.min(allValues),
        yMax: _.max(allValues)
    });
    return _.extend(stateWithSeries, stateWithUnixFromTo);
};
exports.hpTimeSeriesChartReducer = function (state, action) {
    if (state === void 0) { state = initialState; }
    switch (action.type) {
        case actionTypes.GENERATE_RANDOM_DATA:
            return generateRandomData(state, action);
        case actionTypes.SET_DATA:
            return setData(state, action);
    }
};
//# sourceMappingURL=reducers.js.map